Here is some text. Nunc convallis auctor risus, vitae commodo dolor hendrerit nec. Suspendisse tempus pellentesque mattis. In erat velit, fringilla aliquet ullamcorper eget, elementum non dolor. Aliquam erat volutpat.

Maecenas eget pellentesque sem. Duis aliquet augue congue, cursus elit eu, sagittis lacus. 

Lorem ipsum dolor sit amet, consectetur adipiscing elit.

---

Here is a symbol that needs to be converted to something safe: &.


This is **bold**.
This is *italics*.
This is `in-line code`.
This is [link](https://github.com).

Here is **bold text** and **here is some more**.
Here is *italics text* and *here is some more*.
Here is `in-line code` and `here is some more`.
Here is "a quotation" and "here is some more".
Here is [a hyperlink](http://github.com) and [here is another](https://google.com).

This is **not bold text
This is **not bold text **
This is ** not bold text**
This is not bold text**

This is *not italics
This is *not italics *
This is * not italics*
This is not italics*

This is `not in-line code
This is not in-line code`

This is "not a quotation
This is not a quotation"

This is [not a link]
This is [not a link)